#!/bin/bash
dmodule_path="/nfabos/modules"
nosmodule_path="/fabos/modules"
usbmodule_path="/lib/modules/2.6.34.6/kernel/drivers/usb"
diag_console_log="/var/log/diagconsole.log"

##################################
# NAME
#    getSWBD - Output the software board ID
#
# SYNOPSIS
#    getSWBD
#
# DESCRIPTION
#    This function parses the output of the sin command to extract the
#    SWBD value for this platform.
#
#    Use of this function is discouraged. We intend to move the scripts
#    toward a capability of property driven queries instead of parsing
#    model numbers to reduce future maintainence.
#
#
# OPERANDS
#    NONE
##################################

getSWBD()
{
	_abc=`/sbin/sin | \
		  /bin/grep Platform | \
		  /usr/bin/cut -d" " -f2 | \
		  /usr/bin/cut -d"," -f1`
	/bin/echo $_abc
}

product=`getSWBD`

#
# Use nfdiag profile as root profile
#
if [ -f /root/.profile.fabos ];
then
    echo ""
else
    echo "Copying nfdiag.profile to /root/.profile"
    cp /root/.profile /root/.profile.fabos
    cp /nfabos/bin/nfdiag.profile /root/.profile
fi

if [ -f /etc/profile.fabos ];
then
    echo ""
else
    echo "Copying nfdiag.profile to /etc/.profile"
    cp /etc/profile /etc/profile.fabos
    cp /nfabos/bin/nfdiag.profile /etc/profile

fi


#
# modutil <load | unload> <module name>
#
# Load a kernel module, which may be compressed
#
modutil()
{
    cmd=$1
    file=$2
    shift 2
    case $cmd in
    ("load")
        if [ -r /fabos/modules/$file.ko ]
            then if insmod /fabos/modules/$file.ko
            then return
        else RETURN_VALUE=$?
        fi
        elif [ -r /fabos/modules/$file.ko.gz ]
            then if zcat /fabos/modules/$file.ko.gz | insmod - "$@" > ${NULL} 2>&1
            then return
        else RETURN_VALUE=$?
        fi
        else RETURN_VALUE=1 ; echo "modutil: load $file does not exist"
        fi
        echo "Error $RETURN_VALUE returned by insmod while loading $file" >&2
        return $RETURN_VALUE
        ;;
    (*) ;;
    esac
}


#
# Create node for each device driver.
# mk_device <module name> {<device name> <minor-dev-num>}
#
mk_device()
{
    set $@
    node=$1
    shift 1
    major=`grep $node\$ /proc/devices | cut -d ' ' -f 1`
    if [ ! $major ]; then
        $ECHO "No major device for node [$node]. Exiting"
        exit 1;
    fi
    while [ $# -gt 0 ]; do
        rm -f /dev/$1
        mknod --mode=666 /dev/$1 c $major $2
        shift 2
    done
    return 0
}

#
# this function will load the "panic dump" related modules
# These modules need to be loaded first and we have to call
# "pdcheck.sh" to check for a panic dump from a previous reboot
# if found we will save them in CF (it is all done in pdcheck.sh)
#
load_infra()
{
    echo "Installing hv_console module"
	modutil load raslog-module
	#sleep 50
    modutil load basic-module
#    modutil load trace-module platform=${SWBD##SWBD}
    mk_device raslog raslog 0
#    mk_device trace trace 0 trace1 1
#    /sbin/tracecfg -w > /var/log/tracecfg.log
}


case "$1" in
'start')

	# invoke the proper diag pci module
	case "$product" in
		"SWBD1000" | "SWBD1001" | "SWBD1002" ) 
		echo "SWBD1000 MM in M4/M8/M16 Chassis"
        echo "Installing dpci pciehp module"
        /sbin/insmod -f ${dmodule_path}/dpci_pciehp.ko || exit 1
        major=`cat /proc/devices | /bin/grep dpci | cut -f 1 -d" "`
        rm -f /dev/dpci_pciehp.mod
        mknod /dev/dpci_pciehp.mod c $major 0

        echo "Installing dgen module"
        /sbin/insmod -f ${dmodule_path}/dgen-module.ko || exit 1
        major=`cat /proc/devices | /bin/grep dgen | cut -f 1 -d" "`
        rm -f /dev/dgen-module.mod
        mknod /dev/dgen-module.mod c $major 0

        echo "Installing dpregtest module"
        /sbin/insmod -f ${dmodule_path}/dpregtest-module.ko || exit 1
        major=`cat /proc/devices | /bin/grep dpregtest | cut -f 1 -d" "`
        rm -f /dev/dpregtest-module.mod
        mknod /dev/dpregtest-module.mod c $major 0

        echo "Installing dfpga module"
        /sbin/insmod -f ${dmodule_path}/dfpga-module.ko || exit 1
        major=`cat /proc/devices | /bin/grep dfpga | cut -f 1 -d" "`
        rm -f /dev/dfpga-module.mod
        mknod /dev/dfpga-module.mod c $major 0

        #load_infra
        echo "Creating Device file for the USB storage device"
		#echo 1-0:1.0 > /sys/bus/usb/drivers/hub/bind
        #mknod  /dev/sdb b 8 16
        #mknod  /dev/sdb1 b 8 17
        #mknod  /dev/sdb2 b 8 18

        echo "Mounting USB storage device partition with the ext4 filesystem"
        mkdir -p /mntsda1
	    mount -t ext4 /dev/sda1 /mntsda1
        #mkdir -p /usb/usbstorage 
        #mount -t ext4 -o rw,users /dev/sdb1 /usb/usbstorage
    ;;
	"SWBD1004" | "SWBD1005" | "SWBD1006" | "SWBD1007" | "SWBD1008"  | "SWBD1009" | "SWBD1010" | "SWBD1011" )
		echo "SWBD1004/SWBD1005/SWBD1006/SWBD1007/SWBD1008/SWBD1009/SWBD1010/SWBD1011 LC in M4/M8/M16 Chassis"
		echo "Installing dpci switch module"
		/sbin/insmod -f ${dmodule_path}/dpci_switch-module.ko || exit 1
		major=`cat /proc/devices | /bin/grep dpci | cut -f 1 -d" "`
		rm -f /dev/dpci_switch-module.mod
		mknod /dev/dpci_switch-module.mod c $major 0

        echo "Installing dgen module"
        /sbin/insmod -f ${dmodule_path}/dgen-module.ko || exit 1
        major=`cat /proc/devices | /bin/grep dgen | cut -f 1 -d" "`
        rm -f /dev/dgen-module.mod
        mknod /dev/dgen-module.mod c $major 0
 		
   		echo "Installing dfpga module"
        /sbin/insmod -f ${dmodule_path}/dfpga-module.ko || exit 1
        major=`cat /proc/devices | /bin/grep dfpga | cut -f 1 -d" "`
        rm -f /dev/dfpga-module.mod
        mknod /dev/dfpga-module.mod c $major 0

	    echo "Installing dpregtest  module"
        /sbin/insmod -f ${dmodule_path}/dpregtest-module.ko || exit 1
        major=`cat /proc/devices | /bin/grep regtest | cut -f 1 -d" "`
        rm -f /dev/dpregtest-module.mod
        mknod /dev/dpregtest-module.mod c $major 0

        #load_infra
		
        echo "Creating Device file for the USB storage device"
        mknod  /dev/sdb b 8 16
        mknod  /dev/sdb1 b 8 17
        mknod  /dev/sdb2 b 8 18

        echo "Mounting USB/CF storage device partitions with the ext4 filesystem"
        mkdir -p /mntsda1
	    mount -t ext4 /dev/sda1 /mntsda1
        mkdir -p /mntsdb1
	    mount -t ext4 /dev/sdb1 /mntsdb1

	;;
	"SWBD131"| "SWBD132" | "SWBD137" | "SWBD138"   )
		echo "SWBD131/SWBD132/SWBD137/SWBD138"
#TBD by Eden, The eth2,3 is only run on Blackbird. So we need double check it later
		echo "off" > /etc/config/rrd
		echo "link up eth"
		/sbin/ifconfig eth2 up
		/sbin/ifconfig eth3 up
#		/sbin/ifconfig eth4 up

		echo "Installing dpci switch module"
		/sbin/insmod -f ${dmodule_path}/dpci_switch-module.ko || exit 1
		major=`cat /proc/devices | /bin/grep dpci | cut -f 1 -d" "`
		rm -f /dev/dpci_switch-module.mod
		mknod /dev/dpci_switch-module.mod c $major 0

        echo "Installing dgen module"
        /sbin/insmod -f ${dmodule_path}/dgen-module.ko || exit 1
        major=`cat /proc/devices | /bin/grep dgen | cut -f 1 -d" "`
        rm -f /dev/dgen-module.mod
        mknod /dev/dgen-module.mod c $major 0
 		
	    echo "Installing dpregtest  module"
        /sbin/insmod -f ${dmodule_path}/dpregtest-module.ko || exit 1
        major=`cat /proc/devices | /bin/grep regtest | cut -f 1 -d" "`
        rm -f /dev/dpregtest-module.mod
        mknod /dev/dpregtest-module.mod c $major 0
	sleep 2
	/bin/dmesg > $diag_console_log
	/nfabos/bin/nfdiag version | tee -a $diag_console_log

	;;
	
	"SWBD154" | "SWBD164")
		echo "off" > /etc/config/rrd	
		echo "SWBD154 SWBD164"
		echo "Installing dpci switch module"
		/sbin/insmod -f ${dmodule_path}/dpci_switch-module.ko || exit 1
		major=`cat /proc/devices | /bin/grep dpci | cut -f 1 -d" "`
		rm -f /dev/dpci_switch-module.mod
		mknod /dev/dpci_switch-module.mod c $major 0
										
	        echo "Installing dgen module"
	        /sbin/insmod -f ${dmodule_path}/dgen-module.ko || exit 1
	        major=`cat /proc/devices | /bin/grep dgen | cut -f 1 -d" "`
	        rm -f /dev/dgen-module.mod
	        mknod /dev/dgen-module.mod c $major 0
										 		
		echo "Installing dpregtest  module"
	        /sbin/insmod -f ${dmodule_path}/dpregtest-module.ko || exit 1
	        major=`cat /proc/devices | /bin/grep regtest | cut -f 1 -d" "`
	        rm -f /dev/dpregtest-module.mod
	        mknod /dev/dpregtest-module.mod c $major 0
											    
	        echo "Creating Device file for the USB storage device"
	  	echo 1-0:1.0 > /sys/bus/usb/drivers/hub/bind
	        mknod  /dev/sdb b 8 16
	        mknod  /dev/sdb1 b 8 17
	        mknod  /dev/sdb2 b 8 18
	        mkdir -p /usb/usbstorage 

		echo "Disabling OS Daemons"
			# takes effect only during next reboot
			chkconfig sysrmd off 2>/dev/null
			chkconfig superd off 2>/dev/null
			chkconfig crond off 2>/dev/null
			# need to check with experts to disable confd & dcmd gracefully
			rm -rf /etc/rc.d/rc3.d/S70confd 2>/dev/null
			rm -rf /fabos/libexec/DcmClient.Linux.powerpc 2>/dev/null
	;;

	"SWBD153" )
		echo "off" > /etc/config/rrd	
		echo "SWBD153"
		echo "Installing dpci switch module"
		/sbin/insmod -f ${dmodule_path}/dpci_switch-module.ko || exit 1
		major=`cat /proc/devices | /bin/grep dpci | cut -f 1 -d" "`
		rm -f /dev/dpci_switch-module.mod
		mknod /dev/dpci_switch-module.mod c $major 0
										
	        echo "Installing dgen module"
	        /sbin/insmod -f ${dmodule_path}/dgen-module.ko || exit 1
	        major=`cat /proc/devices | /bin/grep dgen | cut -f 1 -d" "`
	        rm -f /dev/dgen-module.mod
	        mknod /dev/dgen-module.mod c $major 0
										 		
		echo "Installing dpregtest  module"
	        /sbin/insmod -f ${dmodule_path}/dpregtest-module.ko || exit 1
	        major=`cat /proc/devices | /bin/grep regtest | cut -f 1 -d" "`
	        rm -f /dev/dpregtest-module.mod
	        mknod /dev/dpregtest-module.mod c $major 0


		echo "Disabling OS Daemons"
			# takes effect only during next reboot
			chkconfig sysrmd off 2>/dev/null
			chkconfig superd off 2>/dev/null
			chkconfig crond off 2>/dev/null
			# need to check with experts to disable confd & dcmd gracefully
			rm -rf /etc/rc.d/rc3.d/S70confd 2>/dev/null
			rm -rf /fabos/libexec/DcmClient.Linux.powerpc 2>/dev/null

		#
		# Use login as quit command, since logout has problem, 
		# execute quit to prompt login message
		if [ -f /bin/quit ];
		then
		    echo ""
		else
		   echo "Copying /bin/login to /bin/quit"
		   cp /bin/login /bin/quit
		fi
	;;
	
	*)
		echo "ERROR: unsupported platform: $product"
		return 1
	;;
	esac

;;
'stop')
    # remove the proper diag pci module
    case "$product" in
		"SWBD1000" | "SWBD1001" | "SWBD1002" ) 
        /sbin/rmmod dpci_pciehp || exit 1
        rm -f /dev/dpci_pciehp.mod
        ;;
        "SWBD1004" | "SWBD1005" | "SWBD1006" | "SWBD1007" | "SWBD1008"  | "SWBD1009" | "SWBD1010" | "SWBD1011" )
        echo "Removing dpci_switch-module"
        /sbin/rmmod dpci_switch-module || exit 1
        rm -f /dev/dpci_switch-module.mod

		echo "Removing dpregtest module"
        /sbin/rmmod dpregtest-module || exit 1
        rm -f /dev/dpregtest-module.mod

		echo "Removing dfpga module" 
        /sbin/rmmod dfpga-module || exit 1
        rm -f /dev/dfpga-module.mod

        ;;
        "SWBD131" | "SWBD132" | "SWBD137" | "SWBD138"  | "SWBD154" | "SWBD164")
        echo "Removing dpci_switch-module"
        /sbin/rmmod dpci_switch-module || exit 1
        rm -f /dev/dpci_switch-module.mod

		echo "Removing dpregtest module"
        /sbin/rmmod dpregtest-module || exit 1
        rm -f /dev/dpregtest-module.mod

        ;;

          "SWBD153"  )
        echo "Removing dpci_switch-module"
        /sbin/rmmod dpci_switch-module || exit 1
        rm -f /dev/dpci_switch-module.mod

	echo "Removing dpregtest module"
        /sbin/rmmod dpregtest-module || exit 1
        rm -f /dev/dpregtest-module.mod


        ;;
        
        *)
        echo "ERROR: unsupported platform: $product"
        return 1
        ;;
    esac

        echo "Removing dgen module"
	/sbin/rmmod dgen_module || exit 1
	rm -f /dev/dgen-module.mod

;;	
*)
    echo "usage: $0 {start | stop}"
;;
esac
